package com.hikcreate.edl.pub.web.mobile.domain.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hikcreate.edl.pub.web.mobile.domain.IBindService;
import com.hikcreate.edl.pub.web.mobile.infra.core.Result;
import com.hikcreate.edl.pub.web.mobile.infra.core.enums.ResultCode;
import com.hikcreate.edl.pub.web.mobile.infra.data.feign.UserDataFegin;
import com.hikcreate.edl.pub.web.mobile.infra.data.mapper.BindInfoMapper;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.UUID;

/**
 * description:客户绑定服务实现类
 *
 * @author: xieshixiang
 * @time：2020/6/18 16:12
 **/
@Service
@EnableScheduling
@Slf4j
public class BindServiceImpl extends ServiceImpl<BindInfoMapper, BindInfo> implements IBindService {

    @Resource
    BindInfoMapper mapper;
    @Resource
    UserDataFegin fegin;


    @Override
    public Result bind(BindInfo info) {
        info.setUnqId(UUID.randomUUID().toString());
        info.setEditorTime(DateTime.now());

        //判断规则1:用户已绑定的车辆不超过3辆
        QueryWrapper boundQuery = new QueryWrapper();
        boundQuery.eq("user_id", info.getUserId());
        Integer bound = mapper.selectCount(boundQuery);
        if (bound >= 3) {
            return Result.errorResult(ResultCode.SERVICE_ERROR, "您的绑定名额已用完!");
        }

        return null;

    }


    @PostConstruct
    public void init() {
        clearPast();
    }

    @Scheduled(cron = "0 0/30 * * * ? ")
    public void clearPast() {
        DateTime now = DateTime.now();
        log.info("开始清除,已过期且无效的绑定信息.当前时间:" + now);
        DateTime lastMonth = DateUtil.offsetDay(now, -30);
        Integer count = mapper.clearPast(lastMonth);
        log.info("清除完毕,共清除过期且无效的绑定信息:" + count);

    }


}
